Lines Matching refs:DeviceReturnTy
20 struct DeviceReturnTy {}; struct
26 typedef DeviceReturnTy (*DeviceFnPtr)();
33 typedef DeviceReturnTy CurrentReturnTy;
48 __device__ DeviceReturnTy dh() { return DeviceReturnTy(); } in dh()
72 extern "C" __device__ DeviceReturnTy cdh() { return DeviceReturnTy(); } in cdh()
85 __device__ DeviceReturnTy d() { return DeviceReturnTy(); } in d()
102 extern "C" __device__ DeviceReturnTy cd() { return DeviceReturnTy(); } in cd()
115 DeviceReturnTy ret_d = d(); // hostdefer-error {{no matching function for call to 'd'}} in hostf()
117 DeviceReturnTy ret_cd = cd(); // hostdefer-error {{no matching function for call to 'cd'}} in hostf()
136 DeviceReturnTy ret_d = d(); in devicef()
138 DeviceReturnTy ret_cd = cd(); in devicef()
146 DeviceReturnTy ret_dh = dh(); in devicef()
148 DeviceReturnTy ret_cdh = cdh(); in devicef()
157 DeviceReturnTy ret_d = d(); in globalf()
159 DeviceReturnTy ret_cd = cd(); in globalf()
167 DeviceReturnTy ret_dh = dh(); in globalf()
169 DeviceReturnTy ret_cdh = cdh(); in globalf()
178 DeviceReturnTy ret_d = d(); in hostdevicef()
180 DeviceReturnTy ret_cd = cd(); in hostdevicef()
309 __device__ DeviceReturnTy template_vs_function(float arg) { in template_vs_function()
310 return DeviceReturnTy(); in template_vs_function()
318 typedef DeviceReturnTy ExpectedReturnTy; in test_host_device_calls_template()
335 DeviceReturnTy ret1 = template_vs_function(1.0f); in test_device_calls_template_fn()
336 DeviceReturnTy ret2 = template_vs_function(2.0); in test_device_calls_template_fn()
376 __device__ DeviceReturnTy device_only_function(int arg) { return DeviceReturnTy(); } in device_only_function()
390 DeviceReturnTy ret1 = device_only_function(1); in test_host_device_single_side_overloading()
407 DeviceReturnTy ret1 = device_only_function(1); in test_host_device_wrong_side_overloading_inline_no_diag()
416 DeviceReturnTy ret1 = device_only_function(1); in test_host_device_wrong_side_overloading_inline_diag()